==> docu_devs_api_client-1.3.4-py3-none-any.whl: docudevs/api/knowledge_bases/promote_knowledge_base.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.case import Case
from ...models.knowledge_bases_controller_promote_knowledge_base_request import (
    KnowledgeBasesControllerPromoteKnowledgeBaseRequest,
)
from ...types import Response


def _get_kwargs(
    *,
    body: KnowledgeBasesControllerPromoteKnowledgeBaseRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/knowledge-bases",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Case]:
    if response.status_code == 200:
        response_200 = Case.from_dict(response.json())

        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Case]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: KnowledgeBasesControllerPromoteKnowledgeBaseRequest,
) -> Response[Case]:
    """
    Args:
        body (KnowledgeBasesControllerPromoteKnowledgeBaseRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Case]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: KnowledgeBasesControllerPromoteKnowledgeBaseRequest,
) -> Optional[Case]:
    """
    Args:
        body (KnowledgeBasesControllerPromoteKnowledgeBaseRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Case
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: KnowledgeBasesControllerPromoteKnowledgeBaseRequest,
) -> Response[Case]:
    """
    Args:
        body (KnowledgeBasesControllerPromoteKnowledgeBaseRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Case]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: KnowledgeBasesControllerPromoteKnowledgeBaseRequest,
) -> Optional[Case]:
    """
    Args:
        body (KnowledgeBasesControllerPromoteKnowledgeBaseRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Case
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed

==> docu_devs_api_client-1.4.7-py3-none-any.whl: docudevs/api/knowledge_bases/promote_knowledge_base.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.knowledge_bases_controller_promote_knowledge_base_request import (
    KnowledgeBasesControllerPromoteKnowledgeBaseRequest,
)
from ...types import Response


def _get_kwargs(
    *,
    body: KnowledgeBasesControllerPromoteKnowledgeBaseRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/knowledge-bases",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Any]:
    if response.status_code == 201:
        return None

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: KnowledgeBasesControllerPromoteKnowledgeBaseRequest,
) -> Response[Any]:
    """
    Args:
        body (KnowledgeBasesControllerPromoteKnowledgeBaseRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: KnowledgeBasesControllerPromoteKnowledgeBaseRequest,
) -> Response[Any]:
    """
    Args:
        body (KnowledgeBasesControllerPromoteKnowledgeBaseRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)
